/************************************************************
   definitions for nutation theory IAU 2000a
   derived from public sources

  Compilation Authors: Dieter Koch and Alois Treindl, Astrodienst Zurich

************************************************************/
/* Copyright (C) 1997 - 2021 Astrodienst AG, Switzerland.  All rights reserved.

  License conditions
  ------------------

  This file is part of Swiss Ephemeris.

  Swiss Ephemeris is distributed with NO WARRANTY OF ANY KIND.  No author
  or distributor accepts any responsibility for the consequences of using it,
  or for whether it serves any particular purpose or works at all, unless he
  or she says so in writing.  

  Swiss Ephemeris is made available by its authors under a dual licensing
  system. The software developer, who uses any part of Swiss Ephemeris
  in his or her software, must choose between one of the two license models,
  which are
  a) GNU Affero General Public License (AGPL)
  b) Swiss Ephemeris Professional License

  The choice must be made before the software developer distributes software
  containing parts of Swiss Ephemeris to others, and before any public
  service using the developed software is activated.

  If the developer choses the AGPL software license, he or she must fulfill
  the conditions of that license, which includes the obligation to place his
  or her whole software project under the AGPL or a compatible license.
  See https://www.gnu.org/licenses/agpl-3.0.html

  If the developer choses the Swiss Ephemeris Professional license,
  he must follow the instructions as found in http://www.astro.com/swisseph/ 
  and purchase the Swiss Ephemeris Professional Edition from Astrodienst
  and sign the corresponding license contract.

  The License grants you the right to use, copy, modify and redistribute
  Swiss Ephemeris, but only under certain conditions described in the License.
  Among other things, the License requires that the copyright notices and
  this notice be preserved on all copies.

  Authors of the Swiss Ephemeris: Dieter Koch and Alois Treindl

  The authors of Swiss Ephemeris have no control or influence over any of
  the derived works, i.e. over software or services created by other
  programmers which use Swiss Ephemeris functions.

  The names of the authors or of the copyright holder (Astrodienst) must not
  be used for promoting any software, product or service which uses or contains
  the Swiss Ephemeris. This copyright notice is the ONLY place where the
  names of the authors can legally appear, except in cases where they have
  given special permission in writing.

  The trademarks 'Swiss Ephemeris' and 'Swiss Ephemeris inside' may be used
  for promoting such software, products or services.
*/

/* 0.1 microarcsecond to degrees */
#define O1MAS2DEG (1 / 3600.0 / 10000000.0)
/* Number of terms in the luni-solar nutation model */
#define NLS 678
#define NLS_2000B 77
/* Number of terms in the planetary nutation model */
#define NPL 687
/* Luni-Solar argument multipliers
L L' F D Om */
static const int16 nls[] = {
0, 0, 0, 0, 1,
0, 0, 2, -2, 2,
0, 0, 2, 0, 2,
0, 0, 0, 0, 2,
0, 1, 0, 0, 0,
0, 1, 2, -2, 2,
1, 0, 0, 0, 0,
0, 0, 2, 0, 1,
1, 0, 2, 0, 2,
0, -1, 2, -2, 2,
0, 0, 2, -2, 1,
-1, 0, 2, 0, 2,
-1, 0, 0, 2, 0,
1, 0, 0, 0, 1,
-1, 0, 0, 0, 1,
-1, 0, 2, 2, 2,
1, 0, 2, 0, 1,
-2, 0, 2, 0, 1,
0, 0, 0, 2, 0,
0, 0, 2, 2, 2,
0, -2, 2, -2, 2,
-2, 0, 0, 2, 0,
2, 0, 2, 0, 2,
1, 0, 2, -2, 2,
-1, 0, 2, 0, 1,
2, 0, 0, 0, 0,
0, 0, 2, 0, 0,
0, 1, 0, 0, 1,
-1, 0, 0, 2, 1,
0, 2, 2, -2, 2,
0, 0, -2, 2, 0,
1, 0, 0, -2, 1,
0, -1, 0, 0, 1,
-1, 0, 2, 2, 1,
0, 2, 0, 0, 0,
1, 0, 2, 2, 2,
-2, 0, 2, 0, 0,
0, 1, 2, 0, 2,
0, 0, 2, 2, 1,
0, -1, 2, 0, 2,
0, 0, 0, 2, 1,
1, 0, 2, -2, 1,
2, 0, 2, -2, 2,
-2, 0, 0, 2, 1,
2, 0, 2, 0, 1,
0, -1, 2, -2, 1,
0, 0, 0, -2, 1,
-1, -1, 0, 2, 0,
2, 0, 0, -2, 1,
1, 0, 0, 2, 0,
0, 1, 2, -2, 1,
1, -1, 0, 0, 0,
-2, 0, 2, 0, 2,
3, 0, 2, 0, 2,
0, -1, 0, 2, 0,
1, -1, 2, 0, 2,
0, 0, 0, 1, 0,
-1, -1, 2, 2, 2,
-1, 0, 2, 0, 0,
0, -1, 2, 2, 2,
-2, 0, 0, 0, 1,
1, 1, 2, 0, 2,
2, 0, 0, 0, 1,
-1, 1, 0, 1, 0,
1, 1, 0, 0, 0,
1, 0, 2, 0, 0,
-1, 0, 2, -2, 1,
1, 0, 0, 0, 2,
-1, 0, 0, 1, 0,
0, 0, 2, 1, 2,
-1, 0, 2, 4, 2,
-1, 1, 0, 1, 1,
0, -2, 2, -2, 1,
1, 0, 2, 2, 1,
-2, 0, 2, 2, 2,
-1, 0, 0, 0, 2,
1, 1, 2, -2, 2,
-2, 0, 2, 4, 2,
-1, 0, 4, 0, 2,
2, 0, 2, -2, 1,
2, 0, 2, 2, 2,
1, 0, 0, 2, 1,
3, 0, 0, 0, 0,
3, 0, 2, -2, 2,
0, 0, 4, -2, 2,
0, 1, 2, 0, 1,
0, 0, -2, 2, 1,
0, 0, 2, -2, 3,
-1, 0, 0, 4, 0,
2, 0, -2, 0, 1,
-2, 0, 0, 4, 0,
-1, -1, 0, 2, 1,
-1, 0, 0, 1, 1,
0, 1, 0, 0, 2,
0, 0, -2, 0, 1,
0, -1, 2, 0, 1,
0, 0, 2, -1, 2,
0, 0, 2, 4, 2,
-2, -1, 0, 2, 0,
1, 1, 0, -2, 1,
-1, 1, 0, 2, 0,
-1, 1, 0, 1, 2,
1, -1, 0, 0, 1,
1, -1, 2, 2, 2,
-1, 1, 2, 2, 2,
3, 0, 2, 0, 1,
0, 1, -2, 2, 0,
-1, 0, 0, -2, 1,
0, 1, 2, 2, 2,
-1, -1, 2, 2, 1,
0, -1, 0, 0, 2,
1, 0, 2, -4, 1,
-1, 0, -2, 2, 0,
0, -1, 2, 2, 1,
2, -1, 2, 0, 2,
0, 0, 0, 2, 2,
1, -1, 2, 0, 1,
-1, 1, 2, 0, 2,
0, 1, 0, 2, 0,
0, -1, -2, 2, 0,
0, 3, 2, -2, 2,
0, 0, 0, 1, 1,
-1, 0, 2, 2, 0,
2, 1, 2, 0, 2,
1, 1, 0, 0, 1,
1, 1, 2, 0, 1,
2, 0, 0, 2, 0,
1, 0, -2, 2, 0,
-1, 0, 0, 2, 2,
0, 1, 0, 1, 0,
0, 1, 0, -2, 1,
-1, 0, 2, -2, 2,
0, 0, 0, -1, 1,
-1, 1, 0, 0, 1,
1, 0, 2, -1, 2,
1, -1, 0, 2, 0,
0, 0, 0, 4, 0,
1, 0, 2, 1, 2,
0, 0, 2, 1, 1,
1, 0, 0, -2, 2,
-1, 0, 2, 4, 1,
1, 0, -2, 0, 1,
1, 1, 2, -2, 1,
0, 0, 2, 2, 0,
-1, 0, 2, -1, 1,
-2, 0, 2, 2, 1,
4, 0, 2, 0, 2,
2, -1, 0, 0, 0,
2, 1, 2, -2, 2,
0, 1, 2, 1, 2,
1, 0, 4, -2, 2,
-1, -1, 0, 0, 1,
0, 1, 0, 2, 1,
-2, 0, 2, 4, 1,
2, 0, 2, 0, 0,
1, 0, 0, 1, 0,
-1, 0, 0, 4, 1,
-1, 0, 4, 0, 1,
2, 0, 2, 2, 1,
0, 0, 2, -3, 2,
-1, -2, 0, 2, 0,
2, 1, 0, 0, 0,
0, 0, 4, 0, 2,
0, 0, 0, 0, 3,
0, 3, 0, 0, 0,
0, 0, 2, -4, 1,
0, -1, 0, 2, 1,
0, 0, 0, 4, 1,
-1, -1, 2, 4, 2,
1, 0, 2, 4, 2,
-2, 2, 0, 2, 0,
-2, -1, 2, 0, 1,
-2, 0, 0, 2, 2,
-1, -1, 2, 0, 2,
0, 0, 4, -2, 1,
3, 0, 2, -2, 1,
-2, -1, 0, 2, 1,
1, 0, 0, -1, 1,
0, -2, 0, 2, 0,
-2, 0, 0, 4, 1,
-3, 0, 0, 0, 1,
1, 1, 2, 2, 2,
0, 0, 2, 4, 1,
3, 0, 2, 2, 2,
-1, 1, 2, -2, 1,
2, 0, 0, -4, 1,
0, 0, 0, -2, 2,
2, 0, 2, -4, 1,
-1, 1, 0, 2, 1,
0, 0, 2, -1, 1,
0, -2, 2, 2, 2,
2, 0, 0, 2, 1,
4, 0, 2, -2, 2,
2, 0, 0, -2, 2,
0, 2, 0, 0, 1,
1, 0, 0, -4, 1,
0, 2, 2, -2, 1,
-3, 0, 0, 4, 0,
-1, 1, 2, 0, 1,
-1, -1, 0, 4, 0,
-1, -2, 2, 2, 2,
-2, -1, 2, 4, 2,
1, -1, 2, 2, 1,
-2, 1, 0, 2, 0,
-2, 1, 2, 0, 1,
2, 1, 0, -2, 1,
-3, 0, 2, 0, 1,
-2, 0, 2, -2, 1,
-1, 1, 0, 2, 2,
0, -1, 2, -1, 2,
-1, 0, 4, -2, 2,
0, -2, 2, 0, 2,
-1, 0, 2, 1, 2,
2, 0, 0, 0, 2,
0, 0, 2, 0, 3,
-2, 0, 4, 0, 2,
-1, 0, -2, 0, 1,
-1, 1, 2, 2, 1,
3, 0, 0, 0, 1,
-1, 0, 2, 3, 2,
2, -1, 2, 0, 1,
0, 1, 2, 2, 1,
0, -1, 2, 4, 2,
2, -1, 2, 2, 2,
0, 2, -2, 2, 0,
-1, -1, 2, -1, 1,
0, -2, 0, 0, 1,
1, 0, 2, -4, 2,
1, -1, 0, -2, 1,
-1, -1, 2, 0, 1,
1, -1, 2, -2, 2,
-2, -1, 0, 4, 0,
-1, 0, 0, 3, 0,
-2, -1, 2, 2, 2,
0, 2, 2, 0, 2,
1, 1, 0, 2, 0,
2, 0, 2, -1, 2,
1, 0, 2, 1, 1,
4, 0, 0, 0, 0,
2, 1, 2, 0, 1,
3, -1, 2, 0, 2,
-2, 2, 0, 2, 1,
1, 0, 2, -3, 1,
1, 1, 2, -4, 1,
-1, -1, 2, -2, 1,
0, -1, 0, -1, 1,
0, -1, 0, -2, 1,
-2, 0, 0, 0, 2,
-2, 0, -2, 2, 0,
-1, 0, -2, 4, 0,
1, -2, 0, 0, 0,
0, 1, 0, 1, 1,
-1, 2, 0, 2, 0,
1, -1, 2, -2, 1,
1, 2, 2, -2, 2,
2, -1, 2, -2, 2,
1, 0, 2, -1, 1,
2, 1, 2, -2, 1,
-2, 0, 0, -2, 1,
1, -2, 2, 0, 2,
0, 1, 2, 1, 1,
1, 0, 4, -2, 1,
-2, 0, 4, 2, 2,
1, 1, 2, 1, 2,
1, 0, 0, 4, 0,
1, 0, 2, 2, 0,
2, 0, 2, 1, 2,
3, 1, 2, 0, 2,
4, 0, 2, 0, 1,
-2, -1, 2, 0, 0,
0, 1, -2, 2, 1,
1, 0, -2, 1, 0,
0, -1, -2, 2, 1,
2, -1, 0, -2, 1,
-1, 0, 2, -1, 2,
1, 0, 2, -3, 2,
0, 1, 2, -2, 3,
0, 0, 2, -3, 1,
-1, 0, -2, 2, 1,
0, 0, 2, -4, 2,
-2, 1, 0, 0, 1,
-1, 0, 0, -1, 1,
2, 0, 2, -4, 2,
0, 0, 4, -4, 4,
0, 0, 4, -4, 2,
-1, -2, 0, 2, 1,
-2, 0, 0, 3, 0,
1, 0, -2, 2, 1,
-3, 0, 2, 2, 2,
-3, 0, 2, 2, 1,
-2, 0, 2, 2, 0,
2, -1, 0, 0, 1,
-2, 1, 2, 2, 2,
1, 1, 0, 1, 0,
0, 1, 4, -2, 2,
-1, 1, 0, -2, 1,
0, 0, 0, -4, 1,
1, -1, 0, 2, 1,
1, 1, 0, 2, 1,
-1, 2, 2, 2, 2,
3, 1, 2, -2, 2,
0, -1, 0, 4, 0,
2, -1, 0, 2, 0,
0, 0, 4, 0, 1,
2, 0, 4, -2, 2,
-1, -1, 2, 4, 1,
1, 0, 0, 4, 1,
1, -2, 2, 2, 2,
0, 0, 2, 3, 2,
-1, 1, 2, 4, 2,
3, 0, 0, 2, 0,
-1, 0, 4, 2, 2,
1, 1, 2, 2, 1,
-2, 0, 2, 6, 2,
2, 1, 2, 2, 2,
-1, 0, 2, 6, 2,
1, 0, 2, 4, 1,
2, 0, 2, 4, 2,
1, 1, -2, 1, 0,
-3, 1, 2, 1, 2,
2, 0, -2, 0, 2,
-1, 0, 0, 1, 2,
-4, 0, 2, 2, 1,
-1, -1, 0, 1, 0,
0, 0, -2, 2, 2,
1, 0, 0, -1, 2,
0, -1, 2, -2, 3,
-2, 1, 2, 0, 0,
0, 0, 2, -2, 4,
-2, -2, 0, 2, 0,
-2, 0, -2, 4, 0,
0, -2, -2, 2, 0,
1, 2, 0, -2, 1,
3, 0, 0, -4, 1,
-1, 1, 2, -2, 2,
1, -1, 2, -4, 1,
1, 1, 0, -2, 2,
-3, 0, 2, 0, 0,
-3, 0, 2, 0, 2,
-2, 0, 0, 1, 0,
0, 0, -2, 1, 0,
-3, 0, 0, 2, 1,
-1, -1, -2, 2, 0,
0, 1, 2, -4, 1,
2, 1, 0, -4, 1,
0, 2, 0, -2, 1,
1, 0, 0, -3, 1,
-2, 0, 2, -2, 2,
-2, -1, 0, 0, 1,
-4, 0, 0, 2, 0,
1, 1, 0, -4, 1,
-1, 0, 2, -4, 1,
0, 0, 4, -4, 1,
0, 3, 2, -2, 2,
-3, -1, 0, 4, 0,
-3, 0, 0, 4, 1,
1, -1, -2, 2, 0,
-1, -1, 0, 2, 2,
1, -2, 0, 0, 1,
1, -1, 0, 0, 2,
0, 0, 0, 1, 2,
-1, -1, 2, 0, 0,
1, -2, 2, -2, 2,
0, -1, 2, -1, 1,
-1, 0, 2, 0, 3,
1, 1, 0, 0, 2,
-1, 1, 2, 0, 0,
1, 2, 0, 0, 0,
-1, 2, 2, 0, 2,
-1, 0, 4, -2, 1,
3, 0, 2, -4, 2,
1, 2, 2, -2, 1,
1, 0, 4, -4, 2,
-2, -1, 0, 4, 1,
0, -1, 0, 2, 2,
-2, 1, 0, 4, 0,
-2, -1, 2, 2, 1,
2, 0, -2, 2, 0,
1, 0, 0, 1, 1,
0, 1, 0, 2, 2,
1, -1, 2, -1, 2,
-2, 0, 4, 0, 1,
2, 1, 0, 0, 1,
0, 1, 2, 0, 0,
0, -1, 4, -2, 2,
0, 0, 4, -2, 4,
0, 2, 2, 0, 1,
-3, 0, 0, 6, 0,
-1, -1, 0, 4, 1,
1, -2, 0, 2, 0,
-1, 0, 0, 4, 2,
-1, -2, 2, 2, 1,
-1, 0, 0, -2, 2,
1, 0, -2, -2, 1,
0, 0, -2, -2, 1,
-2, 0, -2, 0, 1,
0, 0, 0, 3, 1,
0, 0, 0, 3, 0,
-1, 1, 0, 4, 0,
-1, -1, 2, 2, 0,
-2, 0, 2, 3, 2,
1, 0, 0, 2, 2,
0, -1, 2, 1, 2,
3, -1, 0, 0, 0,
2, 0, 0, 1, 0,
1, -1, 2, 0, 0,
0, 0, 2, 1, 0,
1, 0, 2, 0, 3,
3, 1, 0, 0, 0,
3, -1, 2, -2, 2,
2, 0, 2, -1, 1,
1, 1, 2, 0, 0,
0, 0, 4, -1, 2,
1, 2, 2, 0, 2,
-2, 0, 0, 6, 0,
0, -1, 0, 4, 1,
-2, -1, 2, 4, 1,
0, -2, 2, 2, 1,
0, -1, 2, 2, 0,
-1, 0, 2, 3, 1,
-2, 1, 2, 4, 2,
2, 0, 0, 2, 2,
2, -2, 2, 0, 2,
-1, 1, 2, 3, 2,
3, 0, 2, -1, 2,
4, 0, 2, -2, 1,
-1, 0, 0, 6, 0,
-1, -2, 2, 4, 2,
-3, 0, 2, 6, 2,
-1, 0, 2, 4, 0,
3, 0, 0, 2, 1,
3, -1, 2, 0, 1,
3, 0, 2, 0, 0,
1, 0, 4, 0, 2,
5, 0, 2, -2, 2,
0, -1, 2, 4, 1,
2, -1, 2, 2, 1,
0, 1, 2, 4, 2,
1, -1, 2, 4, 2,
3, -1, 2, 2, 2,
3, 0, 2, 2, 1,
5, 0, 2, 0, 2,
0, 0, 2, 6, 2,
4, 0, 2, 2, 2,
0, -1, 1, -1, 1,
-1, 0, 1, 0, 3,
0, -2, 2, -2, 3,
1, 0, -1, 0, 1,
2, -2, 0, -2, 1,
-1, 0, 1, 0, 2,
-1, 0, 1, 0, 1,
-1, -1, 2, -1, 2,
-2, 2, 0, 2, 2,
-1, 0, 1, 0, 0,
-4, 1, 2, 2, 2,
-3, 0, 2, 1, 1,
-2, -1, 2, 0, 2,
1, 0, -2, 1, 1,
2, -1, -2, 0, 1,
-4, 0, 2, 2, 0,
-3, 1, 0, 3, 0,
-1, 0, -1, 2, 0,
0, -2, 0, 0, 2,
0, -2, 0, 0, 2,
-3, 0, 0, 3, 0,
-2, -1, 0, 2, 2,
-1, 0, -2, 3, 0,
-4, 0, 0, 4, 0,
2, 1, -2, 0, 1,
2, -1, 0, -2, 2,
0, 0, 1, -1, 0,
-1, 2, 0, 1, 0,
-2, 1, 2, 0, 2,
1, 1, 0, -1, 1,
1, 0, 1, -2, 1,
0, 2, 0, 0, 2,
1, -1, 2, -3, 1,
-1, 1, 2, -1, 1,
-2, 0, 4, -2, 2,
-2, 0, 4, -2, 1,
-2, -2, 0, 2, 1,
-2, 0, -2, 4, 0,
1, 2, 2, -4, 1,
1, 1, 2, -4, 2,
-1, 2, 2, -2, 1,
2, 0, 0, -3, 1,
-1, 2, 0, 0, 1,
0, 0, 0, -2, 0,
-1, -1, 2, -2, 2,
-1, 1, 0, 0, 2,
0, 0, 0, -1, 2,
-2, 1, 0, 1, 0,
1, -2, 0, -2, 1,
1, 0, -2, 0, 2,
-3, 1, 0, 2, 0,
-1, 1, -2, 2, 0,
-1, -1, 0, 0, 2,
-3, 0, 0, 2, 0,
-3, -1, 0, 2, 0,
2, 0, 2, -6, 1,
0, 1, 2, -4, 2,
2, 0, 0, -4, 2,
-2, 1, 2, -2, 1,
0, -1, 2, -4, 1,
0, 1, 0, -2, 2,
-1, 0, 0, -2, 0,
2, 0, -2, -2, 1,
-4, 0, 2, 0, 1,
-1, -1, 0, -1, 1,
0, 0, -2, 0, 2,
-3, 0, 0, 1, 0,
-1, 0, -2, 1, 0,
-2, 0, -2, 2, 1,
0, 0, -4, 2, 0,
-2, -1, -2, 2, 0,
1, 0, 2, -6, 1,
-1, 0, 2, -4, 2,
1, 0, 0, -4, 2,
2, 1, 2, -4, 2,
2, 1, 2, -4, 1,
0, 1, 4, -4, 4,
0, 1, 4, -4, 2,
-1, -1, -2, 4, 0,
-1, -3, 0, 2, 0,
-1, 0, -2, 4, 1,
-2, -1, 0, 3, 0,
0, 0, -2, 3, 0,
-2, 0, 0, 3, 1,
0, -1, 0, 1, 0,
-3, 0, 2, 2, 0,
1, 1, -2, 2, 0,
-1, 1, 0, 2, 2,
1, -2, 2, -2, 1,
0, 0, 1, 0, 2,
0, 0, 1, 0, 1,
0, 0, 1, 0, 0,
-1, 2, 0, 2, 1,
0, 0, 2, 0, 2,
-2, 0, 2, 0, 2,
2, 0, 0, -1, 1,
3, 0, 0, -2, 1,
1, 0, 2, -2, 3,
1, 2, 0, 0, 1,
2, 0, 2, -3, 2,
-1, 1, 4, -2, 2,
-2, -2, 0, 4, 0,
0, -3, 0, 2, 0,
0, 0, -2, 4, 0,
-1, -1, 0, 3, 0,
-2, 0, 0, 4, 2,
-1, 0, 0, 3, 1,
2, -2, 0, 0, 0,
1, -1, 0, 1, 0,
-1, 0, 0, 2, 0,
0, -2, 2, 0, 1,
-1, 0, 1, 2, 1,
-1, 1, 0, 3, 0,
-1, -1, 2, 1, 2,
0, -1, 2, 0, 0,
-2, 1, 2, 2, 1,
2, -2, 2, -2, 2,
1, 1, 0, 1, 1,
1, 0, 1, 0, 1,
1, 0, 1, 0, 0,
0, 2, 0, 2, 0,
2, -1, 2, -2, 1,
0, -1, 4, -2, 1,
0, 0, 4, -2, 3,
0, 1, 4, -2, 1,
4, 0, 2, -4, 2,
2, 2, 2, -2, 2,
2, 0, 4, -4, 2,
-1, -2, 0, 4, 0,
-1, -3, 2, 2, 2,
-3, 0, 2, 4, 2,
-3, 0, 2, -2, 1,
-1, -1, 0, -2, 1,
-3, 0, 0, 0, 2,
-3, 0, -2, 2, 0,
0, 1, 0, -4, 1,
-2, 1, 0, -2, 1,
-4, 0, 0, 0, 1,
-1, 0, 0, -4, 1,
-3, 0, 0, -2, 1,
0, 0, 0, 3, 2,
-1, 1, 0, 4, 1,
1, -2, 2, 0, 1,
0, 1, 0, 3, 0,
-1, 0, 2, 2, 3,
0, 0, 2, 2, 2,
-2, 0, 2, 2, 2,
-1, 1, 2, 2, 0,
3, 0, 0, 0, 2,
2, 1, 0, 1, 0,
2, -1, 2, -1, 2,
0, 0, 2, 0, 1,
0, 0, 3, 0, 3,
0, 0, 3, 0, 2,
-1, 2, 2, 2, 1,
-1, 0, 4, 0, 0,
1, 2, 2, 0, 1,
3, 1, 2, -2, 1,
1, 1, 4, -2, 2,
-2, -1, 0, 6, 0,
0, -2, 0, 4, 0,
-2, 0, 0, 6, 1,
-2, -2, 2, 4, 2,
0, -3, 2, 2, 2,
0, 0, 0, 4, 2,
-1, -1, 2, 3, 2,
-2, 0, 2, 4, 0,
2, -1, 0, 2, 1,
1, 0, 0, 3, 0,
0, 1, 0, 4, 1,
0, 1, 0, 4, 0,
1, -1, 2, 1, 2,
0, 0, 2, 2, 3,
1, 0, 2, 2, 2,
-1, 0, 2, 2, 2,
-2, 0, 4, 2, 1,
2, 1, 0, 2, 1,
2, 1, 0, 2, 0,
2, -1, 2, 0, 0,
1, 0, 2, 1, 0,
0, 1, 2, 2, 0,
2, 0, 2, 0, 3,
3, 0, 2, 0, 2,
1, 0, 2, 0, 2,
1, 0, 3, 0, 3,
1, 1, 2, 1, 1,
0, 2, 2, 2, 2,
2, 1, 2, 0, 0,
2, 0, 4, -2, 1,
4, 1, 2, -2, 2,
-1, -1, 0, 6, 0,
-3, -1, 2, 6, 2,
-1, 0, 0, 6, 1,
-3, 0, 2, 6, 1,
1, -1, 0, 4, 1,
1, -1, 0, 4, 0,
-2, 0, 2, 5, 2,
1, -2, 2, 2, 1,
3, -1, 0, 2, 0,
1, -1, 2, 2, 0,
0, 0, 2, 3, 1,
-1, 1, 2, 4, 1,
0, 1, 2, 3, 2,
-1, 0, 4, 2, 1,
2, 0, 2, 1, 1,
5, 0, 0, 0, 0,
2, 1, 2, 1, 2,
1, 0, 4, 0, 1,
3, 1, 2, 0, 1,
3, 0, 4, -2, 2,
-2, -1, 2, 6, 2,
0, 0, 0, 6, 0,
0, -2, 2, 4, 2,
-2, 0, 2, 6, 1,
2, 0, 0, 4, 1,
2, 0, 0, 4, 0,
2, -2, 2, 2, 2,
0, 0, 2, 4, 0,
1, 0, 2, 3, 2,
4, 0, 0, 2, 0,
2, 0, 2, 2, 0,
0, 0, 4, 2, 2,
4, -1, 2, 0, 2,
3, 0, 2, 1, 2,
2, 1, 2, 2, 1,
4, 1, 2, 0, 2,
-1, -1, 2, 6, 2,
-1, 0, 2, 6, 1,
1, -1, 2, 4, 1,
1, 1, 2, 4, 2,
3, 1, 2, 2, 2,
5, 0, 2, 0, 1,
2, -1, 2, 4, 2,
2, 0, 2, 4, 1,
};

/* Luni-Solar nutation coefficients, unit 1e-7 arcsec
 * longitude (sin, t*sin, cos), obliquity (cos, t*cos, sin) */
static const int32 cls[] = {
-172064161, -174666, 33386, 92052331, 9086, 15377,
-13170906, -1675, -13696, 5730336, -3015, -4587,
-2276413, -234, 2796, 978459, -485, 1374,
2074554, 207, -698, -897492, 470, -291,
1475877, -3633, 11817, 73871, -184, -1924,
-516821, 1226, -524, 224386, -677, -174,
711159, 73, -872, -6750, 0, 358,
-387298, -367, 380, 200728, 18, 318,
-301461, -36, 816, 129025, -63, 367,
215829, -494, 111, -95929, 299, 132,
128227, 137, 181, -68982, -9, 39,
123457, 11, 19, -53311, 32, -4,
156994, 10, -168, -1235, 0, 82,
63110, 63, 27, -33228, 0, -9,
-57976, -63, -189, 31429, 0, -75,
-59641, -11, 149, 25543, -11, 66,
-51613, -42, 129, 26366, 0, 78,
45893, 50, 31, -24236, -10, 20,
63384, 11, -150, -1220, 0, 29,
-38571, -1, 158, 16452, -11, 68,
32481, 0, 0, -13870, 0, 0,
-47722, 0, -18, 477, 0, -25,
-31046, -1, 131, 13238, -11, 59,
28593, 0, -1, -12338, 10, -3,
20441, 21, 10, -10758, 0, -3,
29243, 0, -74, -609, 0, 13,
25887, 0, -66, -550, 0, 11,
-14053, -25, 79, 8551, -2, -45,
15164, 10, 11, -8001, 0, -1,
-15794, 72, -16, 6850, -42, -5,
21783, 0, 13, -167, 0, 13,
-12873, -10, -37, 6953, 0, -14,
-12654, 11, 63, 6415, 0, 26,
-10204, 0, 25, 5222, 0, 15,
16707, -85, -10, 168, -1, 10,
-7691, 0, 44, 3268, 0, 19,
-11024, 0, -14, 104, 0, 2,
7566, -21, -11, -3250, 0, -5,
-6637, -11, 25, 3353, 0, 14,
-7141, 21, 8, 3070, 0, 4,
-6302, -11, 2, 3272, 0, 4,
5800, 10, 2, -3045, 0, -1,
6443, 0, -7, -2768, 0, -4,
-5774, -11, -15, 3041, 0, -5,
-5350, 0, 21, 2695, 0, 12,
-4752, -11, -3, 2719, 0, -3,
-4940, -11, -21, 2720, 0, -9,
7350, 0, -8, -51, 0, 4,
4065, 0, 6, -2206, 0, 1,
6579, 0, -24, -199, 0, 2,
3579, 0, 5, -1900, 0, 1,
4725, 0, -6, -41, 0, 3,
-3075, 0, -2, 1313, 0, -1,
-2904, 0, 15, 1233, 0, 7,
4348, 0, -10, -81, 0, 2,
-2878, 0, 8, 1232, 0, 4,
-4230, 0, 5, -20, 0, -2,
-2819, 0, 7, 1207, 0, 3,
-4056, 0, 5, 40, 0, -2,
-2647, 0, 11, 1129, 0, 5,
-2294, 0, -10, 1266, 0, -4,
2481, 0, -7, -1062, 0, -3,
2179, 0, -2, -1129, 0, -2,
3276, 0, 1, -9, 0, 0,
-3389, 0, 5, 35, 0, -2,
3339, 0, -13, -107, 0, 1,
-1987, 0, -6, 1073, 0, -2,
-1981, 0, 0, 854, 0, 0,
4026, 0, -353, -553, 0, -139,
1660, 0, -5, -710, 0, -2,
-1521, 0, 9, 647, 0, 4,
1314, 0, 0, -700, 0, 0,
-1283, 0, 0, 672, 0, 0,
-1331, 0, 8, 663, 0, 4,
1383, 0, -2, -594, 0, -2,
1405, 0, 4, -610, 0, 2,
1290, 0, 0, -556, 0, 0,
-1214, 0, 5, 518, 0, 2,
1146, 0, -3, -490, 0, -1,
1019, 0, -1, -527, 0, -1,
-1100, 0, 9, 465, 0, 4,
-970, 0, 2, 496, 0, 1,
1575, 0, -6, -50, 0, 0,
934, 0, -3, -399, 0, -1,
922, 0, -1, -395, 0, -1,
815, 0, -1, -422, 0, -1,
834, 0, 2, -440, 0, 1,
1248, 0, 0, -170, 0, 1,
1338, 0, -5, -39, 0, 0,
716, 0, -2, -389, 0, -1,
1282, 0, -3, -23, 0, 1,
742, 0, 1, -391, 0, 0,
1020, 0, -25, -495, 0, -10,
715, 0, -4, -326, 0, 2,
-666, 0, -3, 369, 0, -1,
-667, 0, 1, 346, 0, 1,
-704, 0, 0, 304, 0, 0,
-694, 0, 5, 294, 0, 2,
-1014, 0, -1, 4, 0, -1,
-585, 0, -2, 316, 0, -1,
-949, 0, 1, 8, 0, -1,
-595, 0, 0, 258, 0, 0,
528, 0, 0, -279, 0, 0,
-590, 0, 4, 252, 0, 2,
570, 0, -2, -244, 0, -1,
-502, 0, 3, 250, 0, 2,
-875, 0, 1, 29, 0, 0,
-492, 0, -3, 275, 0, -1,
535, 0, -2, -228, 0, -1,
-467, 0, 1, 240, 0, 1,
591, 0, 0, -253, 0, 0,
-453, 0, -1, 244, 0, -1,
766, 0, 1, 9, 0, 0,
-446, 0, 2, 225, 0, 1,
-488, 0, 2, 207, 0, 1,
-468, 0, 0, 201, 0, 0,
-421, 0, 1, 216, 0, 1,
463, 0, 0, -200, 0, 0,
-673, 0, 2, 14, 0, 0,
658, 0, 0, -2, 0, 0,
-438, 0, 0, 188, 0, 0,
-390, 0, 0, 205, 0, 0,
639, -11, -2, -19, 0, 0,
412, 0, -2, -176, 0, -1,
-361, 0, 0, 189, 0, 0,
360, 0, -1, -185, 0, -1,
588, 0, -3, -24, 0, 0,
-578, 0, 1, 5, 0, 0,
-396, 0, 0, 171, 0, 0,
565, 0, -1, -6, 0, 0,
-335, 0, -1, 184, 0, -1,
357, 0, 1, -154, 0, 0,
321, 0, 1, -174, 0, 0,
-301, 0, -1, 162, 0, 0,
-334, 0, 0, 144, 0, 0,
493, 0, -2, -15, 0, 0,
494, 0, -2, -19, 0, 0,
337, 0, -1, -143, 0, -1,
280, 0, -1, -144, 0, 0,
309, 0, 1, -134, 0, 0,
-263, 0, 2, 131, 0, 1,
253, 0, 1, -138, 0, 0,
245, 0, 0, -128, 0, 0,
416, 0, -2, -17, 0, 0,
-229, 0, 0, 128, 0, 0,
231, 0, 0, -120, 0, 0,
-259, 0, 2, 109, 0, 1,
375, 0, -1, -8, 0, 0,
252, 0, 0, -108, 0, 0,
-245, 0, 1, 104, 0, 0,
243, 0, -1, -104, 0, 0,
208, 0, 1, -112, 0, 0,
199, 0, 0, -102, 0, 0,
-208, 0, 1, 105, 0, 0,
335, 0, -2, -14, 0, 0,
-325, 0, 1, 7, 0, 0,
-187, 0, 0, 96, 0, 0,
197, 0, -1, -100, 0, 0,
-192, 0, 2, 94, 0, 1,
-188, 0, 0, 83, 0, 0,
276, 0, 0, -2, 0, 0,
-286, 0, 1, 6, 0, 0,
186, 0, -1, -79, 0, 0,
-219, 0, 0, 43, 0, 0,
276, 0, 0, 2, 0, 0,
-153, 0, -1, 84, 0, 0,
-156, 0, 0, 81, 0, 0,
-154, 0, 1, 78, 0, 0,
-174, 0, 1, 75, 0, 0,
-163, 0, 2, 69, 0, 1,
-228, 0, 0, 1, 0, 0,
91, 0, -4, -54, 0, -2,
175, 0, 0, -75, 0, 0,
-159, 0, 0, 69, 0, 0,
141, 0, 0, -72, 0, 0,
147, 0, 0, -75, 0, 0,
-132, 0, 0, 69, 0, 0,
159, 0, -28, -54, 0, 11,
213, 0, 0, -4, 0, 0,
123, 0, 0, -64, 0, 0,
-118, 0, -1, 66, 0, 0,
144, 0, -1, -61, 0, 0,
-121, 0, 1, 60, 0, 0,
-134, 0, 1, 56, 0, 1,
-105, 0, 0, 57, 0, 0,
-102, 0, 0, 56, 0, 0,
120, 0, 0, -52, 0, 0,
101, 0, 0, -54, 0, 0,
-113, 0, 0, 59, 0, 0,
-106, 0, 0, 61, 0, 0,
-129, 0, 1, 55, 0, 0,
-114, 0, 0, 57, 0, 0,
113, 0, -1, -49, 0, 0,
-102, 0, 0, 44, 0, 0,
-94, 0, 0, 51, 0, 0,
-100, 0, -1, 56, 0, 0,
87, 0, 0, -47, 0, 0,
161, 0, 0, -1, 0, 0,
96, 0, 0, -50, 0, 0,
151, 0, -1, -5, 0, 0,
-104, 0, 0, 44, 0, 0,
-110, 0, 0, 48, 0, 0,
-100, 0, 1, 50, 0, 0,
92, 0, -5, 12, 0, -2,
82, 0, 0, -45, 0, 0,
82, 0, 0, -45, 0, 0,
-78, 0, 0, 41, 0, 0,
-77, 0, 0, 43, 0, 0,
2, 0, 0, 54, 0, 0,
94, 0, 0, -40, 0, 0,
-93, 0, 0, 40, 0, 0,
-83, 0, 10, 40, 0, -2,
83, 0, 0, -36, 0, 0,
-91, 0, 0, 39, 0, 0,
128, 0, 0, -1, 0, 0,
-79, 0, 0, 34, 0, 0,
-83, 0, 0, 47, 0, 0,
84, 0, 0, -44, 0, 0,
83, 0, 0, -43, 0, 0,
91, 0, 0, -39, 0, 0,
-77, 0, 0, 39, 0, 0,
84, 0, 0, -43, 0, 0,
-92, 0, 1, 39, 0, 0,
-92, 0, 1, 39, 0, 0,
-94, 0, 0, 0, 0, 0,
68, 0, 0, -36, 0, 0,
-61, 0, 0, 32, 0, 0,
71, 0, 0, -31, 0, 0,
62, 0, 0, -34, 0, 0,
-63, 0, 0, 33, 0, 0,
-73, 0, 0, 32, 0, 0,
115, 0, 0, -2, 0, 0,
-103, 0, 0, 2, 0, 0,
63, 0, 0, -28, 0, 0,
74, 0, 0, -32, 0, 0,
-103, 0, -3, 3, 0, -1,
-69, 0, 0, 30, 0, 0,
57, 0, 0, -29, 0, 0,
94, 0, 0, -4, 0, 0,
64, 0, 0, -33, 0, 0,
-63, 0, 0, 26, 0, 0,
-38, 0, 0, 20, 0, 0,
-43, 0, 0, 24, 0, 0,
-45, 0, 0, 23, 0, 0,
47, 0, 0, -24, 0, 0,
-48, 0, 0, 25, 0, 0,
45, 0, 0, -26, 0, 0,
56, 0, 0, -25, 0, 0,
88, 0, 0, 2, 0, 0,
-75, 0, 0, 0, 0, 0,
85, 0, 0, 0, 0, 0,
49, 0, 0, -26, 0, 0,
-74, 0, -3, -1, 0, -1,
-39, 0, 0, 21, 0, 0,
45, 0, 0, -20, 0, 0,
51, 0, 0, -22, 0, 0,
-40, 0, 0, 21, 0, 0,
41, 0, 0, -21, 0, 0,
-42, 0, 0, 24, 0, 0,
-51, 0, 0, 22, 0, 0,
-42, 0, 0, 22, 0, 0,
39, 0, 0, -21, 0, 0,
46, 0, 0, -18, 0, 0,
-53, 0, 0, 22, 0, 0,
82, 0, 0, -4, 0, 0,
81, 0, -1, -4, 0, 0,
47, 0, 0, -19, 0, 0,
53, 0, 0, -23, 0, 0,
-45, 0, 0, 22, 0, 0,
-44, 0, 0, -2, 0, 0,
-33, 0, 0, 16, 0, 0,
-61, 0, 0, 1, 0, 0,
28, 0, 0, -15, 0, 0,
-38, 0, 0, 19, 0, 0,
-33, 0, 0, 21, 0, 0,
-60, 0, 0, 0, 0, 0,
48, 0, 0, -10, 0, 0,
27, 0, 0, -14, 0, 0,
38, 0, 0, -20, 0, 0,
31, 0, 0, -13, 0, 0,
-29, 0, 0, 15, 0, 0,
28, 0, 0, -15, 0, 0,
-32, 0, 0, 15, 0, 0,
45, 0, 0, -8, 0, 0,
-44, 0, 0, 19, 0, 0,
28, 0, 0, -15, 0, 0,
-51, 0, 0, 0, 0, 0,
-36, 0, 0, 20, 0, 0,
44, 0, 0, -19, 0, 0,
26, 0, 0, -14, 0, 0,
-60, 0, 0, 2, 0, 0,
35, 0, 0, -18, 0, 0,
-27, 0, 0, 11, 0, 0,
47, 0, 0, -1, 0, 0,
36, 0, 0, -15, 0, 0,
-36, 0, 0, 20, 0, 0,
-35, 0, 0, 19, 0, 0,
-37, 0, 0, 19, 0, 0,
32, 0, 0, -16, 0, 0,
35, 0, 0, -14, 0, 0,
32, 0, 0, -13, 0, 0,
65, 0, 0, -2, 0, 0,
47, 0, 0, -1, 0, 0,
32, 0, 0, -16, 0, 0,
37, 0, 0, -16, 0, 0,
-30, 0, 0, 15, 0, 0,
-32, 0, 0, 16, 0, 0,
-31, 0, 0, 13, 0, 0,
37, 0, 0, -16, 0, 0,
31, 0, 0, -13, 0, 0,
49, 0, 0, -2, 0, 0,
32, 0, 0, -13, 0, 0,
23, 0, 0, -12, 0, 0,
-43, 0, 0, 18, 0, 0,
26, 0, 0, -11, 0, 0,
-32, 0, 0, 14, 0, 0,
-29, 0, 0, 14, 0, 0,
-27, 0, 0, 12, 0, 0,
30, 0, 0, 0, 0, 0,
-11, 0, 0, 5, 0, 0,
-21, 0, 0, 10, 0, 0,
-34, 0, 0, 15, 0, 0,
-10, 0, 0, 6, 0, 0,
-36, 0, 0, 0, 0, 0,
-9, 0, 0, 4, 0, 0,
-12, 0, 0, 5, 0, 0,
-21, 0, 0, 5, 0, 0,
-29, 0, 0, -1, 0, 0,
-15, 0, 0, 3, 0, 0,
-20, 0, 0, 0, 0, 0,
28, 0, 0, 0, 0, -2,
17, 0, 0, 0, 0, 0,
-22, 0, 0, 12, 0, 0,
-14, 0, 0, 7, 0, 0,
24, 0, 0, -11, 0, 0,
11, 0, 0, -6, 0, 0,
14, 0, 0, -6, 0, 0,
24, 0, 0, 0, 0, 0,
18, 0, 0, -8, 0, 0,
-38, 0, 0, 0, 0, 0,
-31, 0, 0, 0, 0, 0,
-16, 0, 0, 8, 0, 0,
29, 0, 0, 0, 0, 0,
-18, 0, 0, 10, 0, 0,
-10, 0, 0, 5, 0, 0,
-17, 0, 0, 10, 0, 0,
9, 0, 0, -4, 0, 0,
16, 0, 0, -6, 0, 0,
22, 0, 0, -12, 0, 0,
20, 0, 0, 0, 0, 0,
-13, 0, 0, 6, 0, 0,
-17, 0, 0, 9, 0, 0,
-14, 0, 0, 8, 0, 0,
0, 0, 0, -7, 0, 0,
14, 0, 0, 0, 0, 0,
19, 0, 0, -10, 0, 0,
-34, 0, 0, 0, 0, 0,
-20, 0, 0, 8, 0, 0,
9, 0, 0, -5, 0, 0,
-18, 0, 0, 7, 0, 0,
13, 0, 0, -6, 0, 0,
17, 0, 0, 0, 0, 0,
-12, 0, 0, 5, 0, 0,
15, 0, 0, -8, 0, 0,
-11, 0, 0, 3, 0, 0,
13, 0, 0, -5, 0, 0,
-18, 0, 0, 0, 0, 0,
-35, 0, 0, 0, 0, 0,
9, 0, 0, -4, 0, 0,
-19, 0, 0, 10, 0, 0,
-26, 0, 0, 11, 0, 0,
8, 0, 0, -4, 0, 0,
-10, 0, 0, 4, 0, 0,
10, 0, 0, -6, 0, 0,
-21, 0, 0, 9, 0, 0,
-15, 0, 0, 0, 0, 0,
9, 0, 0, -5, 0, 0,
-29, 0, 0, 0, 0, 0,
-19, 0, 0, 10, 0, 0,
12, 0, 0, -5, 0, 0,
22, 0, 0, -9, 0, 0,
-10, 0, 0, 5, 0, 0,
-20, 0, 0, 11, 0, 0,
-20, 0, 0, 0, 0, 0,
-17, 0, 0, 7, 0, 0,
15, 0, 0, -3, 0, 0,
8, 0, 0, -4, 0, 0,
14, 0, 0, 0, 0, 0,
-12, 0, 0, 6, 0, 0,
25, 0, 0, 0, 0, 0,
-13, 0, 0, 6, 0, 0,
-14, 0, 0, 8, 0, 0,
13, 0, 0, -5, 0, 0,
-17, 0, 0, 9, 0, 0,
-12, 0, 0, 6, 0, 0,
-10, 0, 0, 5, 0, 0,
10, 0, 0, -6, 0, 0,
-15, 0, 0, 0, 0, 0,
-22, 0, 0, 0, 0, 0,
28, 0, 0, -1, 0, 0,
15, 0, 0, -7, 0, 0,
23, 0, 0, -10, 0, 0,
12, 0, 0, -5, 0, 0,
29, 0, 0, -1, 0, 0,
-25, 0, 0, 1, 0, 0,
22, 0, 0, 0, 0, 0,
-18, 0, 0, 0, 0, 0,
15, 0, 0, 3, 0, 0,
-23, 0, 0, 0, 0, 0,
12, 0, 0, -5, 0, 0,
-8, 0, 0, 4, 0, 0,
-19, 0, 0, 0, 0, 0,
-10, 0, 0, 4, 0, 0,
21, 0, 0, -9, 0, 0,
23, 0, 0, -1, 0, 0,
-16, 0, 0, 8, 0, 0,
-19, 0, 0, 9, 0, 0,
-22, 0, 0, 10, 0, 0,
27, 0, 0, -1, 0, 0,
16, 0, 0, -8, 0, 0,
19, 0, 0, -8, 0, 0,
9, 0, 0, -4, 0, 0,
-9, 0, 0, 4, 0, 0,
-9, 0, 0, 4, 0, 0,
-8, 0, 0, 4, 0, 0,
18, 0, 0, -9, 0, 0,
16, 0, 0, -1, 0, 0,
-10, 0, 0, 4, 0, 0,
-23, 0, 0, 9, 0, 0,
16, 0, 0, -1, 0, 0,
-12, 0, 0, 6, 0, 0,
-8, 0, 0, 4, 0, 0,
30, 0, 0, -2, 0, 0,
24, 0, 0, -10, 0, 0,
10, 0, 0, -4, 0, 0,
-16, 0, 0, 7, 0, 0,
-16, 0, 0, 7, 0, 0,
17, 0, 0, -7, 0, 0,
-24, 0, 0, 10, 0, 0,
-12, 0, 0, 5, 0, 0,
-24, 0, 0, 11, 0, 0,
-23, 0, 0, 9, 0, 0,
-13, 0, 0, 5, 0, 0,
-15, 0, 0, 7, 0, 0,
0, 0, -1988, 0, 0, -1679,
0, 0, -63, 0, 0, -27,
-4, 0, 0, 0, 0, 0,
0, 0, 5, 0, 0, 4,
5, 0, 0, -3, 0, 0,
0, 0, 364, 0, 0, 176,
0, 0, -1044, 0, 0, -891,
-3, 0, 0, 1, 0, 0,
4, 0, 0, -2, 0, 0,
0, 0, 330, 0, 0, 0,
5, 0, 0, -2, 0, 0,
3, 0, 0, -2, 0, 0,
-3, 0, 0, 1, 0, 0,
-5, 0, 0, 2, 0, 0,
3, 0, 0, -1, 0, 0,
3, 0, 0, 0, 0, 0,
3, 0, 0, 0, 0, 0,
0, 0, 5, 0, 0, 0,
0, 0, 0, 1, 0, 0,
4, 0, 0, -2, 0, 0,
6, 0, 0, 0, 0, 0,
5, 0, 0, -2, 0, 0,
-7, 0, 0, 0, 0, 0,
-12, 0, 0, 0, 0, 0,
5, 0, 0, -3, 0, 0,
3, 0, 0, -1, 0, 0,
-5, 0, 0, 0, 0, 0,
3, 0, 0, 0, 0, 0,
-7, 0, 0, 3, 0, 0,
7, 0, 0, -4, 0, 0,
0, 0, -12, 0, 0, -10,
4, 0, 0, -2, 0, 0,
3, 0, 0, -2, 0, 0,
-3, 0, 0, 2, 0, 0,
-7, 0, 0, 3, 0, 0,
-4, 0, 0, 2, 0, 0,
-3, 0, 0, 1, 0, 0,
0, 0, 0, 0, 0, 0,
-3, 0, 0, 1, 0, 0,
7, 0, 0, -3, 0, 0,
-4, 0, 0, 2, 0, 0,
4, 0, 0, -2, 0, 0,
-5, 0, 0, 3, 0, 0,
5, 0, 0, 0, 0, 0,
-5, 0, 0, 2, 0, 0,
5, 0, 0, -2, 0, 0,
-8, 0, 0, 3, 0, 0,
9, 0, 0, 0, 0, 0,
6, 0, 0, -3, 0, 0,
-5, 0, 0, 2, 0, 0,
3, 0, 0, 0, 0, 0,
-7, 0, 0, 0, 0, 0,
-3, 0, 0, 1, 0, 0,
5, 0, 0, 0, 0, 0,
3, 0, 0, 0, 0, 0,
-3, 0, 0, 2, 0, 0,
4, 0, 0, -2, 0, 0,
3, 0, 0, -1, 0, 0,
-5, 0, 0, 2, 0, 0,
4, 0, 0, -2, 0, 0,
9, 0, 0, -3, 0, 0,
4, 0, 0, 0, 0, 0,
4, 0, 0, -2, 0, 0,
-3, 0, 0, 2, 0, 0,
-4, 0, 0, 2, 0, 0,
9, 0, 0, -3, 0, 0,
-4, 0, 0, 0, 0, 0,
-4, 0, 0, 0, 0, 0,
3, 0, 0, -2, 0, 0,
8, 0, 0, 0, 0, 0,
3, 0, 0, 0, 0, 0,
-3, 0, 0, 2, 0, 0,
3, 0, 0, -1, 0, 0,
3, 0, 0, -1, 0, 0,
-3, 0, 0, 1, 0, 0,
6, 0, 0, -3, 0, 0,
3, 0, 0, 0, 0, 0,
-3, 0, 0, 1, 0, 0,
-7, 0, 0, 0, 0, 0,
9, 0, 0, 0, 0, 0,
-3, 0, 0, 2, 0, 0,
-3, 0, 0, 0, 0, 0,
-4, 0, 0, 0, 0, 0,
-5, 0, 0, 3, 0, 0,
-13, 0, 0, 0, 0, 0,
-7, 0, 0, 0, 0, 0,
10, 0, 0, 0, 0, 0,
3, 0, 0, -1, 0, 0,
10, 0, 13, 6, 0, -5,
0, 0, 30, 0, 0, 14,
0, 0, -162, 0, 0, -138,
0, 0, 75, 0, 0, 0,
-7, 0, 0, 4, 0, 0,
-4, 0, 0, 2, 0, 0,
4, 0, 0, -2, 0, 0,
5, 0, 0, -2, 0, 0,
5, 0, 0, -3, 0, 0,
-3, 0, 0, 0, 0, 0,
-3, 0, 0, 2, 0, 0,
-4, 0, 0, 2, 0, 0,
-5, 0, 0, 2, 0, 0,
6, 0, 0, 0, 0, 0,
9, 0, 0, 0, 0, 0,
5, 0, 0, 0, 0, 0,
-7, 0, 0, 0, 0, 0,
-3, 0, 0, 1, 0, 0,
-4, 0, 0, 2, 0, 0,
7, 0, 0, 0, 0, 0,
-4, 0, 0, 0, 0, 0,
4, 0, 0, 0, 0, 0,
-6, 0, -3, 3, 0, 1,
0, 0, -3, 0, 0, -2,
11, 0, 0, 0, 0, 0,
3, 0, 0, -1, 0, 0,
11, 0, 0, 0, 0, 0,
-3, 0, 0, 2, 0, 0,
-1, 0, 3, 3, 0, -1,
4, 0, 0, -2, 0, 0,
0, 0, -13, 0, 0, -11,
3, 0, 6, 0, 0, 0,
-7, 0, 0, 0, 0, 0,
5, 0, 0, -3, 0, 0,
-3, 0, 0, 1, 0, 0,
3, 0, 0, 0, 0, 0,
5, 0, 0, -3, 0, 0,
-7, 0, 0, 3, 0, 0,
8, 0, 0, -3, 0, 0,
-4, 0, 0, 2, 0, 0,
11, 0, 0, 0, 0, 0,
-3, 0, 0, 1, 0, 0,
3, 0, 0, -1, 0, 0,
-4, 0, 0, 2, 0, 0,
8, 0, 0, -4, 0, 0,
3, 0, 0, -1, 0, 0,
11, 0, 0, 0, 0, 0,
-6, 0, 0, 3, 0, 0,
-4, 0, 0, 2, 0, 0,
-8, 0, 0, 4, 0, 0,
-7, 0, 0, 3, 0, 0,
-4, 0, 0, 2, 0, 0,
3, 0, 0, -1, 0, 0,
6, 0, 0, -3, 0, 0,
-6, 0, 0, 3, 0, 0,
6, 0, 0, 0, 0, 0,
6, 0, 0, -1, 0, 0,
5, 0, 0, -2, 0, 0,
-5, 0, 0, 2, 0, 0,
-4, 0, 0, 0, 0, 0,
-4, 0, 0, 2, 0, 0,
4, 0, 0, 0, 0, 0,
6, 0, 0, -3, 0, 0,
-4, 0, 0, 2, 0, 0,
0, 0, -26, 0, 0, -11,
0, 0, -10, 0, 0, -5,
5, 0, 0, -3, 0, 0,
-13, 0, 0, 0, 0, 0,
3, 0, 0, -2, 0, 0,
4, 0, 0, -2, 0, 0,
7, 0, 0, -3, 0, 0,
4, 0, 0, 0, 0, 0,
5, 0, 0, 0, 0, 0,
-3, 0, 0, 2, 0, 0,
-6, 0, 0, 2, 0, 0,
-5, 0, 0, 2, 0, 0,
-7, 0, 0, 3, 0, 0,
5, 0, 0, -2, 0, 0,
13, 0, 0, 0, 0, 0,
-4, 0, 0, 2, 0, 0,
-3, 0, 0, 0, 0, 0,
5, 0, 0, -2, 0, 0,
-11, 0, 0, 0, 0, 0,
5, 0, 0, -2, 0, 0,
4, 0, 0, 0, 0, 0,
4, 0, 0, -2, 0, 0,
-4, 0, 0, 2, 0, 0,
6, 0, 0, -3, 0, 0,
3, 0, 0, -2, 0, 0,
-12, 0, 0, 0, 0, 0,
4, 0, 0, 0, 0, 0,
-3, 0, 0, 0, 0, 0,
-4, 0, 0, 0, 0, 0,
3, 0, 0, 0, 0, 0,
3, 0, 0, -1, 0, 0,
-3, 0, 0, 1, 0, 0,
0, 0, -5, 0, 0, -2,
-7, 0, 0, 4, 0, 0,
6, 0, 0, -3, 0, 0,
-3, 0, 0, 0, 0, 0,
5, 0, 0, -3, 0, 0,
3, 0, 0, -1, 0, 0,
3, 0, 0, 0, 0, 0,
-3, 0, 0, 1, 0, 0,
-5, 0, 0, 3, 0, 0,
-3, 0, 0, 2, 0, 0,
-3, 0, 0, 2, 0, 0,
12, 0, 0, 0, 0, 0,
3, 0, 0, -1, 0, 0,
-4, 0, 0, 2, 0, 0,
4, 0, 0, 0, 0, 0,
6, 0, 0, 0, 0, 0,
5, 0, 0, -3, 0, 0,
4, 0, 0, -2, 0, 0,
-6, 0, 0, 3, 0, 0,
4, 0, 0, -2, 0, 0,
6, 0, 0, -3, 0, 0,
6, 0, 0, 0, 0, 0,
-6, 0, 0, 3, 0, 0,
3, 0, 0, -2, 0, 0,
7, 0, 0, -4, 0, 0,
4, 0, 0, -2, 0, 0,
-5, 0, 0, 2, 0, 0,
5, 0, 0, 0, 0, 0,
-6, 0, 0, 3, 0, 0,
-6, 0, 0, 3, 0, 0,
-4, 0, 0, 2, 0, 0,
10, 0, 0, 0, 0, 0,
-4, 0, 0, 2, 0, 0,
7, 0, 0, 0, 0, 0,
7, 0, 0, -3, 0, 0,
4, 0, 0, 0, 0, 0,
11, 0, 0, 0, 0, 0,
5, 0, 0, -2, 0, 0,
-6, 0, 0, 2, 0, 0,
4, 0, 0, -2, 0, 0,
3, 0, 0, -2, 0, 0,
5, 0, 0, -2, 0, 0,
-4, 0, 0, 2, 0, 0,
-4, 0, 0, 2, 0, 0,
-3, 0, 0, 2, 0, 0,
4, 0, 0, -2, 0, 0,
3, 0, 0, -1, 0, 0,
-3, 0, 0, 1, 0, 0,
-3, 0, 0, 1, 0, 0,
-3, 0, 0, 2, 0, 0,
};

/*#if NUT_IAU_2000A*/
/* Planetary argument multipliers
 * L L' F D Om Me Ve E Ma Ju Sa Ur Ne pre */
static const int16 npl[] = {
0, 0, 0, 0, 0, 0, 0, 8,-16, 4, 5, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -8, 16, -4, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 8,-16, 4, 5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 2, 2,
0, 0, 0, 0, 0, 0, 0, -4, 8, -1, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, -8, 3, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, 3, -8, 3, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 10, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 6, -3, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, -8, 3, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -5, 8, -3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -4, 8, -3, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 4, -8, 1, 5, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 6, 4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -5, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -1, 0, 2, -5, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -5, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, -2, 5, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 5, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 5, 0, 0, 2,
2, 0, -1, -1, 0, 0, 0, 3, -7, 0, 0, 0, 0, 0,
1, 0, 0, -2, 0, 0, 19,-21, 3, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 2, -4, 0, -3, 0, 0, 0, 0,
1, 0, 0, -1, 1, 0, 0, -1, 0, 2, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, -4, 10, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 0, 2, 0, 0, -5, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -7, 4, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 1, -1, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 0, 2, 0, -2, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 18,-16, 0, 0, 0, 0, 0, 0,
-2, 0, 1, 1, 2, 0, 0, 1, 0, -2, 0, 0, 0, 0,
-1, 0, 1, -1, 1, 0, 18,-17, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 1, 1, 0, 0, 2, -2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -8, 13, 0, 0, 0, 0, 0, 2,
0, 0, 2, -2, 2, 0, -8, 11, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -8, 13, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -8, 12, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 8,-13, 0, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 8,-14, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 8,-13, 0, 0, 0, 0, 0, 1,
-2, 0, 0, 2, 1, 0, 0, 2, 0, -4, 5, 0, 0, 0,
-2, 0, 0, 2, 2, 0, 3, -3, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -3, 1, 0, 0, 0,
0, 0, 0, 0, 1, 0, 3, -5, 0, 2, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -4, 3, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -1, 2, 0, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -2, 2, 0, 0, 0, 0, 0,
-1, 0, 1, 0, 1, 0, 3, -5, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 1, 0, 0, 3, -4, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -2, -2, 0, 0, 0,
-2, 0, 2, 0, 2, 0, 0, -5, 9, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, 0, -1, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, 0, 0, 2, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2,
-1, 0, 0, 1, 0, 0, 0, 3, -4, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 0, 2, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -1, 0, 0, 2, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -9, 17, 0, 0, 0, 0, 0,
0, 0, 0, 0, 2, 0, -3, 5, 0, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, -1, 2, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0,
1, 0, 0, -2, 0, 0, 17,-16, 0, -2, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 1, -3, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 0, 5, -6, 0, 0, 0, 0, 0,
0, 0, -2, 2, 0, 0, 0, 9,-13, 0, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -1, 0, 0, 1, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0,
0, 0, -2, 2, 0, 0, 5, -6, 0, 0, 0, 0, 0, 0,
0, 0, -1, 1, 1, 0, 5, -7, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 6, -8, 0, 0, 0, 0, 0, 0,
2, 0, 1, -3, 1, 0, -6, 7, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0,
0, 0, -1, 1, 1, 0, 0, 1, 0, 1, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, 0, 2, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2,
0, 0, 0, 0, 0, 0, 0, -8, 15, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -8, 15, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -9, 15, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 8,-15, 0, 0, 0, 0, 0,
1, 0, -1, -1, 0, 0, 0, 8,-15, 0, 0, 0, 0, 0,
2, 0, 0, -2, 0, 0, 2, -5, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -5, 5, 0, 0, 0,
2, 0, 0, -2, 1, 0, 0, -6, 8, 0, 0, 0, 0, 0,
2, 0, 0, -2, 1, 0, 0, -2, 0, 3, 0, 0, 0, 0,
-2, 0, 1, 1, 0, 0, 0, 1, 0, -3, 0, 0, 0, 0,
-2, 0, 1, 1, 1, 0, 0, 1, 0, -3, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -3, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 6, -8, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -1, -5, 0, 0, 0,
-1, 0, 0, 1, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
-1, 0, 1, 1, 1, 0,-20, 20, 0, 0, 0, 0, 0, 0,
1, 0, 0, -2, 0, 0, 20,-21, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 8,-15, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0,-10, 15, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, -2, 4, 0, 0, 0,
2, 0, 0, -2, 1, 0, -6, 8, 0, 0, 0, 0, 0, 0,
0, 0, -2, 2, 1, 0, 5, -6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, -1, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, 1, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2,
0, 0, 2, -2, 1, 0, 0, -9, 13, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 7,-13, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 5, -6, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 9,-17, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -9, 17, 0, 0, 0, 0, 2,
1, 0, 0, -1, 1, 0, 0, -3, 4, 0, 0, 0, 0, 0,
1, 0, 0, -1, 1, 0, -3, 4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 2, 0, 0, -1, 2, 0, 0, 0, 0, 0,
0, 0, -1, 1, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0,
0, 0, -2, 2, 0, 1, 0, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -5, 0, 2, 0, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 0, 2, 0, -3, 1, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 3, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 8,-13, 0, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 8,-12, 0, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, -8, 11, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 1, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0,
-1, 0, 0, 0, 1, 0, 18,-16, 0, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, -1, 1, 0, 0, 0,
0, 0, 0, 0, 1, 0, 3, -7, 4, 0, 0, 0, 0, 0,
-2, 0, 1, 1, 1, 0, 0, -3, 7, 0, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -1, 0, -2, 5, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 0, 0, -2, 5, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -4, 8, -3, 0, 0, 0, 0,
1, 0, 0, 0, 1, 0,-10, 3, 0, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -2, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 0, 1, 0, 10, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 4, -8, 3, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 0, 0, 2, -5, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 2, -5, 0, 0, 0,
2, 0, -1, -1, 1, 0, 0, 3, -7, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, 0, -5, 0, 0, 0,
0, 0, 0, 0, 1, 0, -3, 7, -4, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
1, 0, 0, 0, 1, 0,-18, 16, 0, 0, 0, 0, 0, 0,
-2, 0, 1, 1, 1, 0, 0, 1, 0, -2, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, -8, 12, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, -8, 13, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, 0, -2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -2, 2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 2, 0, 0, 0, 0, 1,
-1, 0, 0, 1, 1, 0, 3, -4, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 1, 1, 0, 0, 3, -4, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, -2, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, 2, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 2,
0, 0, 1, -1, 0, 0, 3, -6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, -3, 5, 0, 0, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, -3, 4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -2, 4, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, -5, 6, 0, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 5, -7, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 5, -8, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 6, -8, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -8, 15, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 0, 2, 0, -3, 0, 0, 0, 0,
-2, 0, 0, 2, 1, 0, 0, 6, -8, 0, 0, 0, 0, 0,
1, 0, 0, -1, 1, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -5, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, -1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2,
0, 0, 1, -1, 2, 0, 0, -1, 0, 0, -1, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -7, 13, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 7,-13, 0, 0, 0, 0, 0,
2, 0, 0, -2, 1, 0, 0, -5, 6, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -8, 11, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, -1, 0, 2, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 4, -4, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0, 0,
0, 0, 1, -1, 1, 0, 0, -1, 0, 0, 3, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 2,
-2, 0, 0, 2, 0, 0, 3, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 2, 0, 0, -4, 8, -3, 0, 0, 0, 0,
0, 0, 0, 0, 2, 0, 0, 4, -8, 3, 0, 0, 0, 0,
2, 0, 0, -2, 1, 0, 0, -2, 0, 2, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -1, 0, 2, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, 0, -2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 1, -2, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, 0, -2, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -2, 0, 0, 2, 0, 0, 0,
0, 0, 1, -1, 1, 0, 3, -6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -5, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 3, -5, 0, 0, 0, 0, 0, 0,
0, 0, 1, -1, 1, 0, -3, 4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -3, 5, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -3, 5, 0, 0, 0, 0, 0, 2,
0, 0, 2, -2, 2, 0, -3, 3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -3, 5, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, -4, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, 1, -4, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, -4, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -2, 4, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -3, 4, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -2, 4, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, -2, 4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 8, 0, 0, 0, 0, 0, 2,
0, 0, 2, -2, 2, 0, -5, 6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -5, 8, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 8, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -5, 7, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -5, 8, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 5, -8, 0, 0, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, 0, -1, 0, -1, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -2, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -6, 11, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6,-11, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, -1, 0, 4, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 1, 0, -4, 0, 0, 0, 0, 0, 0,
2, 0, 0, -2, 1, 0, -3, 3, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 2, 0, 0, -2, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -7, 9, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 4, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -1, 0, 2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 2,
0, 0, 2, -2, 2, 0, 0, -2, 0, 2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 2,
0, 0, 0, 0, 1, 0, 3, -5, 0, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 3, -4, 0, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, -3, 3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 2, -4, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -4, 4, 0, 0, 0, 0, 0,
0, 0, 1, -1, 2, 0, -5, 7, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 3, -6, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -3, 6, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -4, 6, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -3, 6, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, -3, 6, 0, 0, 0, 0, 2,
0, 0, -1, 1, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 2, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -5, 9, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -5, 9, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 5, -9, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 0, 1, 0, -2, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -2, 0, 2, 0, 0, 0, 0,
-2, 0, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0,
0, 0, -2, 2, 0, 0, 3, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -6, 10, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -6, 10, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -2, 3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -2, 3, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -2, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, -3, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, -1, 0, 3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, -8, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -4, 8, 0, 0, 0, 0, 2,
0, 0, -2, 2, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -4, 7, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -4, 7, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 4, -7, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, -2, 3, 0, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -2, 0, 3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -5, 10, 0, 0, 0, 0, 2,
0, 0, 0, 0, 1, 0, -1, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -3, 5, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -3, 5, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 3, -5, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 1, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -1, 2, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -1, 2, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -7, 11, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -7, 11, 0, 0, 0, 0, 0, 1,
0, 0, -2, 2, 0, 0, 4, -4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, -3, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, -4, 4, 0, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 4, -5, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -4, 7, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -4, 6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -4, 7, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -4, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -4, 6, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -4, 5, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -4, 6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 4, -6, 0, 0, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0,
0, 0, -1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 1, -1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 0, 5, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, -3, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 3, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -7, 12, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -1, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 1, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -2, 5, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 0, 4, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, 0, -4, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, -1, 1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -6, 10, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -6, 10, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -3, 0, 3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -3, 7, 0, 0, 0, 0, 2,
-2, 0, 0, 2, 0, 0, 4, -4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -5, 8, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, -8, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 0, 3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 0, 3, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 1, 0, -3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, -4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -2, 4, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -2, 3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -2, 4, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -6, 9, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -6, 9, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 6, -9, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 1, 0, -2, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, -2, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -4, 6, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, -6, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 3, -4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 0, 2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, 0, -2, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -5, 9, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, -4, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -3, 4, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -3, 4, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 3, -4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -4, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 1, 0, 0, 2, -2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -1, 0, 2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -3, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 1, -5, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 1, 0, -3, 5, 0, 0, 0,
0, 0, 0, 0, 1, 0, -3, 4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, -2, 2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -8, 14, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, 0, 2, -5, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 5, -8, 3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 5, -8, 3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 3, -8, 3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -3, 8, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, 0, -2, 5, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 12, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 12, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 1, -2, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0, 2,
0, 0, 2, -2, 1, 0, -5, 5, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 3, -6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -3, 6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -3, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 7, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 7, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -5, 6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 5, -7, 0, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 0, 0, 0, -1, 0, 3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -2, 6, 0, 0, 0, 0, 2,
0, 0, 0, 0, 1, 0, 2, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -6, 9, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, -9, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -2, 2, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -2, 1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -5, 7, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, -7, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, -2, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 4, -5, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -1, 3, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, -1, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -1, 3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -7, 10, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -7, 10, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -4, 8, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -4, 5, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -4, 5, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 4, -5, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -2, 0, 5, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -9, 13, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 5, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -2, 0, 4, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, -4, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -2, 7, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, -3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -2, 5, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -2, 5, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -6, 8, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -6, 8, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 6, -8, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 1, 0, 0, 2, 0, -2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -3, 9, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, -6, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 5, -6, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 10, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, -4, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 4, -4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -3, 3, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -3, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, -5, 13, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -2, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -2, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 3, -2, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 3, -2, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -1, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -6, 15, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 15, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -3, 9, -4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 2, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -2, 8, -1, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, -8, 3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1,
0, 0, 1, -1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -6, 16, -4, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -2, 8, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -2, 8, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, -8, 1, 5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 3, -5, 4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 11, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 11, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -8, 11, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 2,
0, 0, 0, 0, 0, 0, 3, -3, 0, 2, 0, 0, 0, 2,
0, 0, 2, -2, 1, 0, 0, 4, -8, 3, 0, 0, 0, 0,
0, 0, 1, -1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 0, -4, 8, -3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -3, 7, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 5, -6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 5, -6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 6, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 7, -9, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 2, -1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, -1, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, -7, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, -5, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -1, 4, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -1, 4, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -7, 9, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -7, 9, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 4, -3, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, -1, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -4, 4, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 4, -4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 4, -4, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 4, -4, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -3, 0, 5, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -9, 12, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, -4, 0, 0, 0, 0,
0, 0, 2, -2, 1, 0, 1, -1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 7, -8, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, -3, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 3, 0, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -2, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -6, 7, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 6, -7, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 6, -6, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, -2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 3, 0, -2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, -4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 3, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -2, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, -1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, -1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, 0, -2, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, -2, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, 0, -1, 0, 0, 2,
0, 0, 2, -2, 1, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, -8, 16, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, 2, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 7, -8, 3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -5, 16, -4, -5, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, -1, 8, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 10, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 10, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -8, 10, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -3, 8, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -5, 5, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 5, -5, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 5, -5, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 5, -5, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 7, -7, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 7, -7, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, -5, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 7, -8, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 5, -3, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 4, -3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -9, 11, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -9, 11, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 4, 0, -4, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, 0, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -6, 6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 6, -6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 6, -6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 4, 0, -2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, -4, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 3, -1, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 3, -1, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 3, -1, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, 0, -1, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, 0, 0, -2, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, -2, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 8, -9, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 5, -4, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -7, 7, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 7, -7, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 5, 0, -4, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, 0, -3, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 5, 0, -2, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -8, 8, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 8, -8, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 5, -3, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 5, -3, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, -9, 9, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -9, 9, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, -9, 9, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 9, -9, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 6, -4, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1,
0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2,
1, 0, 0, -2, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
1, 0, 0, -2, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0,
1, 0, 0, -2, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
1, 0, 0, -2, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
-1, 0, 0, 2, 0, 0, 0, 4, -8, 3, 0, 0, 0, 0,
1, 0, 0, -2, 0, 0, 0, 4, -8, 3, 0, 0, 0, 0,
-2, 0, 0, 2, 0, 0, 0, 4, -8, 3, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 0, 2, 0, -3, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 2, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0,
1, 0, -1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 2, 0, 0, 0, 2, 0, -3, 0, 0, 0, 0,
-2, 0, 0, 0, 0, 0, 0, 2, 0, -3, 0, 0, 0, 0,
1, 0, 0, 0, 0, 0, 0, 4, -8, 3, 0, 0, 0, 0,
-1, 0, 1, -1, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0,
1, 0, 1, -1, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0,
-1, 0, 0, 0, 0, 0, 0, 4, -8, 3, 0, 0, 0, 0,
-1, 0, 0, 2, 1, 0, 0, 2, 0, -2, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
-1, 0, 0, 2, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
-1, 0, 0, 2, 0, 0, 3, -3, 0, 0, 0, 0, 0, 0,
1, 0, 0, -2, 1, 0, 0, -2, 0, 2, 0, 0, 0, 0,
1, 0, 2, -2, 2, 0, -3, 3, 0, 0, 0, 0, 0, 0,
1, 0, 2, -2, 2, 0, 0, -2, 0, 2, 0, 0, 0, 0,
1, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0,
1, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 0, -2, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0,
0, 0, 0, -2, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, -2, 2, 0, 0, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 0, -1, 0, 1, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, -1, 1, 0, 0, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, -2, 3, 0, 0, 0, 0, 0, 0,
0, 0, 0, 2, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0,
0, 0, 1, 1, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0,
1, 0, 2, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0,
-1, 0, 2, 0, 2, 0, 10, -3, 0, 0, 0, 0, 0, 0,
0, 0, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0,
1, 0, 2, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 0, 4, -8, 3, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 0, -4, 8, -3, 0, 0, 0, 0,
-1, 0, 2, 0, 2, 0, 0, -4, 8, -3, 0, 0, 0, 0,
2, 0, 2, -2, 2, 0, 0, -2, 0, 3, 0, 0, 0, 0,
1, 0, 2, 0, 1, 0, 0, -2, 0, 3, 0, 0, 0, 0,
0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0,
-1, 0, 2, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0,
-2, 0, 2, 2, 2, 0, 0, 2, 0, -2, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 2, -3, 0, 0, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 1, -1, 0, 0, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 0, 1, 0, -1, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 2, -2, 0, 0, 0, 0, 0, 0,
-1, 0, 2, 2, 2, 0, 0, -1, 0, 1, 0, 0, 0, 0,
1, 0, 2, 0, 2, 0, -1, 1, 0, 0, 0, 0, 0, 0,
-1, 0, 2, 2, 2, 0, 0, 2, 0, -3, 0, 0, 0, 0,
2, 0, 2, 0, 2, 0, 0, 2, 0, -3, 0, 0, 0, 0,
1, 0, 2, 0, 2, 0, 0, -4, 8, -3, 0, 0, 0, 0,
1, 0, 2, 0, 2, 0, 0, 4, -8, 3, 0, 0, 0, 0,
1, 0, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0,
0, 0, 2, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0,
2, 0, 2, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0,
-1, 0, 2, 2, 2, 0, 0, 2, 0, -2, 0, 0, 0, 0,
-1, 0, 2, 2, 2, 0, 3, -3, 0, 0, 0, 0, 0, 0,
1, 0, 2, 0, 2, 0, 1, -1, 0, 0, 0, 0, 0, 0,
0, 0, 2, 2, 2, 0, 0, 2, 0, -2, 0, 0, 0, 0,
};

/* Planetary nutation coefficients, unit 1e-7 arcsec
 * longitude (sin, cos), obliquity (sin, cos) */
static const int16 icpl[] = {
1440, 0, 0, 0,
56, -117, -42, -40,
125, -43, 0, -54,
0, 5, 0, 0,
3, -7, -3, 0,
3, 0, 0, -2,
-114, 0, 0, 61,
-219, 89, 0, 0,
-3, 0, 0, 0,
-462, 1604, 0, 0,
99, 0, 0, -53,
-3, 0, 0, 2,
0, 6, 2, 0,
3, 0, 0, 0,
-12, 0, 0, 0,
14, -218, 117, 8,
31, -481, -257, -17,
-491, 128, 0, 0,
-3084, 5123, 2735, 1647,
-1444, 2409, -1286, -771,
11, -24, -11, -9,
26, -9, 0, 0,
103, -60, 0, 0,
0, -13, -7, 0,
-26, -29, -16, 14,
9, -27, -14, -5,
12, 0, 0, -6,
-7, 0, 0, 0,
0, 24, 0, 0,
284, 0, 0, -151,
226, 101, 0, 0,
0, -8, -2, 0,
0, -6, -3, 0,
5, 0, 0, -3,
-41, 175, 76, 17,
0, 15, 6, 0,
425, 212, -133, 269,
1200, 598, 319, -641,
235, 334, 0, 0,
11, -12, -7, -6,
5, -6, 3, 3,
-5, 0, 0, 3,
6, 0, 0, -3,
15, 0, 0, 0,
13, 0, 0, -7,
-6, -9, 0, 0,
266, -78, 0, 0,
-460, -435, -232, 246,
0, 15, 7, 0,
-3, 0, 0, 2,
0, 131, 0, 0,
4, 0, 0, 0,
0, 3, 0, 0,
0, 4, 2, 0,
0, 3, 0, 0,
-17, -19, -10, 9,
-9, -11, 6, -5,
-6, 0, 0, 3,
-16, 8, 0, 0,
0, 3, 0, 0,
11, 24, 11, -5,
-3, -4, -2, 1,
3, 0, 0, -1,
0, -8, -4, 0,
0, 3, 0, 0,
0, 5, 0, 0,
0, 3, 2, 0,
-6, 4, 2, 3,
-3, -5, 0, 0,
-5, 0, 0, 2,
4, 24, 13, -2,
-42, 20, 0, 0,
-10, 233, 0, 0,
-3, 0, 0, 1,
78, -18, 0, 0,
0, 3, 1, 0,
0, -3, -1, 0,
0, -4, -2, 1,
0, -8, -4, -1,
0, -5, 3, 0,
-7, 0, 0, 3,
-14, 8, 3, 6,
0, 8, -4, 0,
0, 19, 10, 0,
45, -22, 0, 0,
-3, 0, 0, 0,
0, -3, 0, 0,
0, 3, 0, 0,
3, 5, 3, -2,
89, -16, -9, -48,
0, 3, 0, 0,
-3, 7, 4, 2,
-349, -62, 0, 0,
-15, 22, 0, 0,
-3, 0, 0, 0,
-53, 0, 0, 0,
5, 0, 0, -3,
0, -8, 0, 0,
15, -7, -4, -8,
-3, 0, 0, 1,
-21, -78, 0, 0,
20, -70, -37, -11,
0, 6, 3, 0,
5, 3, 2, -2,
-17, -4, -2, 9,
0, 6, 3, 0,
32, 15, -8, 17,
174, 84, 45, -93,
11, 56, 0, 0,
-66, -12, -6, 35,
47, 8, 4, -25,
0, 8, 4, 0,
10, -22, -12, -5,
-3, 0, 0, 2,
-24, 12, 0, 0,
5, -6, 0, 0,
3, 0, 0, -2,
4, 3, 1, -2,
0, 29, 15, 0,
-5, -4, -2, 2,
8, -3, -1, -5,
0, -3, 0, 0,
10, 0, 0, 0,
3, 0, 0, -2,
-5, 0, 0, 3,
46, 66, 35, -25,
-14, 7, 0, 0,
0, 3, 2, 0,
-5, 0, 0, 0,
-68, -34, -18, 36,
0, 14, 7, 0,
10, -6, -3, -5,
-5, -4, -2, 3,
-3, 5, 2, 1,
76, 17, 9, -41,
84, 298, 159, -45,
3, 0, 0, -1,
-3, 0, 0, 2,
-3, 0, 0, 1,
-82, 292, 156, 44,
-73, 17, 9, 39,
-9, -16, 0, 0,
3, 0, -1, -2,
-3, 0, 0, 0,
-9, -5, -3, 5,
-439, 0, 0, 0,
57, -28, -15, -30,
0, -6, -3, 0,
-4, 0, 0, 2,
-40, 57, 30, 21,
23, 7, 3, -13,
273, 80, 43, -146,
-449, 430, 0, 0,
-8, -47, -25, 4,
6, 47, 25, -3,
0, 23, 13, 0,
-3, 0, 0, 2,
3, -4, -2, -2,
-48, -110, -59, 26,
51, 114, 61, -27,
-133, 0, 0, 57,
0, 4, 0, 0,
-21, -6, -3, 11,
0, -3, -1, 0,
-11, -21, -11, 6,
-18, -436, -233, 9,
35, -7, 0, 0,
0, 5, 3, 0,
11, -3, -1, -6,
-5, -3, -1, 3,
-53, -9, -5, 28,
0, 3, 2, 1,
4, 0, 0, -2,
0, -4, 0, 0,
-50, 194, 103, 27,
-13, 52, 28, 7,
-91, 248, 0, 0,
6, 49, 26, -3,
-6, -47, -25, 3,
0, 5, 3, 0,
52, 23, 10, -23,
-3, 0, 0, 1,
0, 5, 3, 0,
-4, 0, 0, 0,
-4, 8, 3, 2,
10, 0, 0, 0,
3, 0, 0, -2,
0, 8, 4, 0,
0, 8, 4, 1,
-4, 0, 0, 0,
-4, 0, 0, 0,
-8, 4, 2, 4,
8, -4, -2, -4,
0, 15, 7, 0,
-138, 0, 0, 0,
0, -7, -3, 0,
0, -7, -3, 0,
54, 0, 0, -29,
0, 10, 4, 0,
-7, 0, 0, 3,
-37, 35, 19, 20,
0, 4, 0, 0,
-4, 9, 0, 0,
8, 0, 0, -4,
-9, -14, -8, 5,
-3, -9, -5, 3,
-145, 47, 0, 0,
-10, 40, 21, 5,
11, -49, -26, -7,
-2150, 0, 0, 932,
-12, 0, 0, 5,
85, 0, 0, -37,
4, 0, 0, -2,
3, 0, 0, -2,
-86, 153, 0, 0,
-6, 9, 5, 3,
9, -13, -7, -5,
-8, 12, 6, 4,
-51, 0, 0, 22,
-11, -268, -116, 5,
0, 12, 5, 0,
0, 7, 3, 0,
31, 6, 3, -17,
140, 27, 14, -75,
57, 11, 6, -30,
-14, -39, 0, 0,
0, -6, -2, 0,
4, 15, 8, -2,
0, 4, 0, 0,
-3, 0, 0, 1,
0, 11, 5, 0,
9, 6, 0, 0,
-4, 10, 4, 2,
5, 3, 0, 0,
16, 0, 0, -9,
-3, 0, 0, 0,
0, 3, 2, -1,
7, 0, 0, -3,
-25, 22, 0, 0,
42, 223, 119, -22,
-27, -143, -77, 14,
9, 49, 26, -5,
-1166, 0, 0, 505,
-5, 0, 0, 2,
-6, 0, 0, 3,
-8, 0, 1, 4,
0, -4, 0, 0,
117, 0, 0, -63,
-4, 8, 4, 2,
3, 0, 0, -2,
-5, 0, 0, 2,
0, 31, 0, 0,
-5, 0, 1, 3,
4, 0, 0, -2,
-4, 0, 0, 2,
-24, -13, -6, 10,
3, 0, 0, 0,
0, -32, -17, 0,
8, 12, 5, -3,
3, 0, 0, -1,
7, 13, 0, 0,
-3, 16, 0, 0,
50, 0, 0, -27,
0, -5, -3, 0,
13, 0, 0, 0,
0, 5, 3, 1,
24, 5, 2, -11,
5, -11, -5, -2,
30, -3, -2, -16,
18, 0, 0, -9,
8, 614, 0, 0,
3, -3, -1, -2,
6, 17, 9, -3,
-3, -9, -5, 2,
0, 6, 3, -1,
-127, 21, 9, 55,
3, 5, 0, 0,
-6, -10, -4, 3,
5, 0, 0, 0,
16, 9, 4, -7,
3, 0, 0, -2,
0, 22, 0, 0,
0, 19, 10, 0,
7, 0, 0, -4,
0, -5, -2, 0,
0, 3, 1, 0,
-9, 3, 1, 4,
17, 0, 0, -7,
0, -3, -2, -1,
-20, 34, 0, 0,
-10, 0, 1, 5,
-4, 0, 0, 2,
22, -87, 0, 0,
-4, 0, 0, 2,
-3, -6, -2, 1,
-16, -3, -1, 7,
0, -3, -2, 0,
4, 0, 0, 0,
-68, 39, 0, 0,
27, 0, 0, -14,
0, -4, 0, 0,
-25, 0, 0, 0,
-12, -3, -2, 6,
3, 0, 0, -1,
3, 66, 29, -1,
490, 0, 0, -213,
-22, 93, 49, 12,
-7, 28, 15, 4,
-3, 13, 7, 2,
-46, 14, 0, 0,
-5, 0, 0, 0,
2, 1, 0, 0,
0, -3, 0, 0,
-28, 0, 0, 15,
5, 0, 0, -2,
0, 3, 0, 0,
-11, 0, 0, 5,
0, 3, 1, 0,
-3, 0, 0, 1,
25, 106, 57, -13,
5, 21, 11, -3,
1485, 0, 0, 0,
-7, -32, -17, 4,
0, 5, 3, 0,
-6, -3, -2, 3,
30, -6, -2, -13,
-4, 4, 0, 0,
-19, 0, 0, 10,
0, 4, 2, -1,
0, 3, 0, 0,
4, 0, 0, -2,
0, -3, -1, 0,
-3, 0, 0, 0,
5, 3, 1, -2,
0, 11, 0, 0,
118, 0, 0, -52,
0, -5, -3, 0,
-28, 36, 0, 0,
5, -5, 0, 0,
14, -59, -31, -8,
0, 9, 5, 1,
-458, 0, 0, 198,
0, -45, -20, 0,
9, 0, 0, -5,
0, -3, 0, 0,
0, -4, -2, -1,
11, 0, 0, -6,
6, 0, 0, -2,
-16, 23, 0, 0,
0, -4, -2, 0,
-5, 0, 0, 2,
-166, 269, 0, 0,
15, 0, 0, -8,
10, 0, 0, -4,
-78, 45, 0, 0,
0, -5, -2, 0,
7, 0, 0, -4,
-5, 328, 0, 0,
3, 0, 0, -2,
5, 0, 0, -2,
0, 3, 1, 0,
-3, 0, 0, 0,
-3, 0, 0, 0,
0, -4, -2, 0,
-1223, -26, 0, 0,
0, 7, 3, 0,
3, 0, 0, 0,
0, 3, 2, 0,
-6, 20, 0, 0,
-368, 0, 0, 0,
-75, 0, 0, 0,
11, 0, 0, -6,
3, 0, 0, -2,
-3, 0, 0, 1,
-13, -30, 0, 0,
21, 3, 0, 0,
-3, 0, 0, 1,
-4, 0, 0, 2,
8, -27, 0, 0,
-19, -11, 0, 0,
-4, 0, 0, 2,
0, 5, 2, 0,
-6, 0, 0, 2,
-8, 0, 0, 0,
-1, 0, 0, 0,
-14, 0, 0, 6,
6, 0, 0, 0,
-74, 0, 0, 32,
0, -3, -1, 0,
4, 0, 0, -2,
8, 11, 0, 0,
0, 3, 2, 0,
-262, 0, 0, 114,
0, -4, 0, 0,
-7, 0, 0, 4,
0, -27, -12, 0,
-19, -8, -4, 8,
202, 0, 0, -87,
-8, 35, 19, 5,
0, 4, 2, 0,
16, -5, 0, 0,
5, 0, 0, -3,
0, -3, 0, 0,
1, 0, 0, 0,
-35, -48, -21, 15,
-3, -5, -2, 1,
6, 0, 0, -3,
3, 0, 0, -1,
0, -5, 0, 0,
12, 55, 29, -6,
0, 5, 3, 0,
-598, 0, 0, 0,
-3, -13, -7, 1,
-5, -7, -3, 2,
3, 0, 0, -1,
5, -7, 0, 0,
4, 0, 0, -2,
16, -6, 0, 0,
8, -3, 0, 0,
8, -31, -16, -4,
0, 3, 1, 0,
113, 0, 0, -49,
0, -24, -10, 0,
4, 0, 0, -2,
27, 0, 0, 0,
-3, 0, 0, 1,
0, -4, -2, 0,
5, 0, 0, -2,
0, -3, 0, 0,
-13, 0, 0, 6,
5, 0, 0, -2,
-18, -10, -4, 8,
-4, -28, 0, 0,
-5, 6, 3, 2,
-3, 0, 0, 1,
-5, -9, -4, 2,
17, 0, 0, -7,
11, 4, 0, 0,
0, -6, -2, 0,
83, 15, 0, 0,
-4, 0, 0, 2,
0, -114, -49, 0,
117, 0, 0, -51,
-5, 19, 10, 2,
-3, 0, 0, 0,
-3, 0, 0, 2,
0, -3, -1, 0,
3, 0, 0, 0,
0, -6, -2, 0,
393, 3, 0, 0,
-4, 21, 11, 2,
-6, 0, -1, 3,
-3, 8, 4, 1,
8, 0, 0, 0,
18, -29, -13, -8,
8, 34, 18, -4,
89, 0, 0, 0,
3, 12, 6, -1,
54, -15, -7, -24,
0, 3, 0, 0,
3, 0, 0, -1,
0, 35, 0, 0,
-154, -30, -13, 67,
15, 0, 0, 0,
0, 4, 2, 0,
0, 9, 0, 0,
80, -71, -31, -35,
0, -20, -9, 0,
11, 5, 2, -5,
61, -96, -42, -27,
14, 9, 4, -6,
-11, -6, -3, 5,
0, -3, -1, 0,
123, -415, -180, -53,
0, 0, 0, -35,
-5, 0, 0, 0,
7, -32, -17, -4,
0, -9, -5, 0,
0, -4, 2, 0,
-89, 0, 0, 38,
0, -86, -19, -6,
0, 0, -19, 6,
-123, -416, -180, 53,
0, -3, -1, 0,
12, -6, -3, -5,
-13, 9, 4, 6,
0, -15, -7, 0,
3, 0, 0, -1,
-62, -97, -42, 27,
-11, 5, 2, 5,
0, -19, -8, 0,
-3, 0, 0, 1,
0, 4, 2, 0,
0, 3, 0, 0,
0, 4, 2, 0,
-85, -70, -31, 37,
163, -12, -5, -72,
-63, -16, -7, 28,
-21, -32, -14, 9,
0, -3, -1, 0,
3, 0, 0, -2,
0, 8, 0, 0,
3, 10, 4, -1,
3, 0, 0, -1,
0, -7, -3, 0,
0, -4, -2, 0,
6, 19, 0, 0,
5, -173, -75, -2,
0, -7, -3, 0,
7, -12, -5, -3,
-3, 0, 0, 2,
3, -4, -2, -1,
74, 0, 0, -32,
-3, 12, 6, 2,
26, -14, -6, -11,
19, 0, 0, -8,
6, 24, 13, -3,
83, 0, 0, 0,
0, -10, -5, 0,
11, -3, -1, -5,
3, 0, 1, -1,
3, 0, 0, -1,
-4, 0, 0, 0,
5, -23, -12, -3,
-339, 0, 0, 147,
0, -10, -5, 0,
5, 0, 0, 0,
3, 0, 0, -1,
0, -4, -2, 0,
18, -3, 0, 0,
9, -11, -5, -4,
-8, 0, 0, 4,
3, 0, 0, -1,
0, 9, 0, 0,
6, -9, -4, -2,
-4, -12, 0, 0,
67, -91, -39, -29,
30, -18, -8, -13,
0, 0, 0, 0,
0, -114, -50, 0,
0, 0, 0, 23,
517, 16, 7, -224,
0, -7, -3, 0,
143, -3, -1, -62,
29, 0, 0, -13,
-4, 0, 0, 2,
-6, 0, 0, 3,
5, 12, 5, -2,
-25, 0, 0, 11,
-3, 0, 0, 1,
0, 4, 2, 0,
-22, 12, 5, 10,
50, 0, 0, -22,
0, 7, 4, 0,
0, 3, 1, 0,
-4, 4, 2, 2,
-5, -11, -5, 2,
0, 4, 2, 0,
4, 17, 9, -2,
59, 0, 0, 0,
0, -4, -2, 0,
-8, 0, 0, 4,
-3, 0, 0, 0,
4, -15, -8, -2,
370, -8, 0, -160,
0, 0, -3, 0,
0, 3, 1, 0,
-6, 3, 1, 3,
0, 6, 0, 0,
-10, 0, 0, 4,
0, 9, 4, 0,
4, 17, 7, -2,
34, 0, 0, -15,
0, 5, 3, 0,
-5, 0, 0, 2,
-37, -7, -3, 16,
3, 13, 7, -2,
40, 0, 0, 0,
0, -3, -2, 0,
-184, -3, -1, 80,
-3, 0, 0, 1,
-3, 0, 0, 0,
0, -10, -6, -1,
31, -6, 0, -13,
-3, -32, -14, 1,
-7, 0, 0, 3,
0, -8, -4, 0,
3, -4, 0, 0,
0, 4, 0, 0,
0, 3, 1, 0,
19, -23, -10, 2,
0, 0, 0, -10,
0, 3, 2, 0,
0, 9, 5, -1,
28, 0, 0, 0,
0, -7, -4, 0,
8, -4, 0, -4,
0, 0, -2, 0,
0, 3, 0, 0,
-3, 0, 0, 1,
-9, 0, 1, 4,
3, 12, 5, -1,
17, -3, -1, 0,
0, 7, 4, 0,
19, 0, 0, 0,
0, -5, -3, 0,
14, -3, 0, -1,
0, 0, -1, 0,
0, 0, 0, -5,
0, 5, 3, 0,
13, 0, 0, 0,
0, -3, -2, 0,
2, 9, 4, 3,
0, 0, 0, -4,
8, 0, 0, 0,
0, 4, 2, 0,
6, 0, 0, -3,
6, 0, 0, 0,
0, 3, 1, 0,
5, 0, 0, -2,
3, 0, 0, -1,
-3, 0, 0, 0,
6, 0, 0, 0,
7, 0, 0, 0,
-4, 0, 0, 0,
4, 0, 0, 0,
6, 0, 0, 0,
0, -4, 0, 0,
0, -4, 0, 0,
5, 0, 0, 0,
-3, 0, 0, 0,
4, 0, 0, 0,
-5, 0, 0, 0,
4, 0, 0, 0,
0, 3, 0, 0,
13, 0, 0, 0,
21, 11, 0, 0,
0, -5, 0, 0,
0, -5, -2, 0,
0, 5, 3, 0,
0, -5, 0, 0,
-3, 0, 0, 2,
20, 10, 0, 0,
-34, 0, 0, 0,
-19, 0, 0, 0,
3, 0, 0, -2,
-3, 0, 0, 1,
-6, 0, 0, 3,
-4, 0, 0, 0,
3, 0, 0, 0,
3, 0, 0, 0,
4, 0, 0, 0,
3, 0, 0, -1,
6, 0, 0, -3,
-8, 0, 0, 3,
0, 3, 1, 0,
-3, 0, 0, 0,
0, -3, -2, 0,
126, -63, -27, -55,
-5, 0, 1, 2,
-3, 28, 15, 2,
5, 0, 1, -2,
0, 9, 4, 1,
0, 9, 4, -1,
-126, -63, -27, 55,
3, 0, 0, -1,
21, -11, -6, -11,
0, -4, 0, 0,
-21, -11, -6, 11,
-3, 0, 0, 1,
0, 3, 1, 0,
8, 0, 0, -4,
-6, 0, 0, 3,
-3, 0, 0, 1,
3, 0, 0, -1,
-3, 0, 0, 1,
-5, 0, 0, 2,
24, -12, -5, -11,
0, 3, 1, 0,
0, 3, 1, 0,
0, 3, 2, 0,
-24, -12, -5, 10,
4, 0, -1, -2,
13, 0, 0, -6,
7, 0, 0, -3,
3, 0, 0, -1,
3, 0, 0, -1,
};
/*#endif  * NUT_IAU_2000A */
